@@ -33,10 +33,11 @@ import km3db
 import km3db.extras
 from docopt import docopt
 
-
 log = logging.getLogger("streamds")
 
-RUNSUMMARY_URL = "https://km3netdbweb.in2p3.fr/jsonds/runsummarynumbers/i"
+RUNSUMMARYNUMBERS_URL = "https://km3netdbweb.in2p3.fr/jsonds/runsummarynumbers/i"
+RUNSUMMARYSTRINGS_URL = "https://km3netdbweb.in2p3.fr/jsonds/runsummarystrings/i"
+RUNSUMMARYSTRINGS_COLUMNS = set(["UUID", "JPP"])
 REQUIRED_COLUMNS = set(["run", "det_id", "source"])
 
 
@@ -62,10 +63,9 @@ def get_data(stream, parameters, fmt, outfile=None, groupby=None):
     if parameters:
         for parameter in parameters:
             if "=" not in parameter:
-                log.error(
-                    "Invalid parameter syntax '{}'\n"
-                    "The correct syntax is 'parameter=value'".format(parameter)
-                )
+                log.error("Invalid parameter syntax '{}'\n"
+                          "The correct syntax is 'parameter=value'".format(
+                              parameter))
                 continue
             key, value = parameter.split("=")
             params[key] = value
@@ -154,11 +154,8 @@ def upload_runsummary(csv_filename, testrun=False, verify=False):
     cols = set(df.columns)
 
     if not REQUIRED_COLUMNS.issubset(cols):
-        log.error(
-            "Missing columns: {}.".format(
-                ", ".join(str(c) for c in REQUIRED_COLUMNS - cols)
-            )
-        )
+        log.error("Missing columns: {}.".format(', '.join(
+            str(c) for c in REQUIRED_COLUMNS - cols)))
         return
 
     parameters = cols - REQUIRED_COLUMNS
@@ -170,9 +167,8 @@ def upload_runsummary(csv_filename, testrun=False, verify=False):
         log.critical("Empty dataset.")
         return
 
-    print(
-        "Found data for parameters: {}.".format(", ".join(str(c) for c in parameters))
-    )
+    print("Found data for parameters: {}.".format(', '.join(
+        str(c) for c in parameters)))
     print("Converting CSV data into JSON")
     if testrun:
         log.warn("Test run: adding 'TEST_' prefix to parameter names")
@@ -180,27 +176,41 @@ def upload_runsummary(csv_filename, testrun=False, verify=False):
     else:
         prefix = ""
 
-    db = km3db.DBManager()  # noqa
-
-    det_id_zero_mask = df["det_id"] == 0
+    det_id_zero_mask = df['det_id'] == 0
     if sum(det_id_zero_mask) > 0:
         log.warning("Entries with 'det_id=0' found, removing them.")
         df = df[~det_id_zero_mask]
     df["det_id"] = df["det_id"].apply(km3db.tools.todetoid)
     print(df)
-    data = convert_runsummary_to_json(df, prefix=prefix)
-    print("We have {:.3f} MB to upload.".format(len(data) / 1024**2))
+
+    data_runsummarynumbers = convert_runsummary_to_json(
+        df[df.columns.difference(RUNSUMMARYSTRINGS_COLUMNS)], prefix=prefix)
+    print("We have {:.3f} MB runsummarynumbers to upload.".format(
+        len(data_runsummarynumbers) / 1024**2))
+    _database_upload(data_runsummarynumbers, verify)
+
+    data_runsummarystrings = convert_runsummary_to_json(
+        df[REQUIRED_COLUMNS.union(RUNSUMMARYSTRINGS_COLUMNS)],
+        prefix=prefix,
+        isrunsummarystrings=True)
+    print("We have {:.3f} MB runsummarystrings to upload.".format(
+        len(data_runsummarystrings) / 1024**2))
+    _database_upload(data_runsummarystrings, verify, isrunsummarystrings=True)
+
+
+def _database_upload(data, verify=False, isrunsummarystrings=False):
+    db = km3db.DBManager()  # noqa
 
     print("Requesting database session.")
     session_cookie = db.session_cookie
 
     print("Uploading the data to the database.")
-    r = requests.post(
-        RUNSUMMARY_URL,
-        cookies={"sid": session_cookie},
-        files={"datafile": data},
-        verify=verify,
-    )
+    url = RUNSUMMARYSTRINGS_URL if isrunsummarystrings else RUNSUMMARYNUMBERS_URL
+    print("URL: {}".format(url))
+    r = requests.post(url,
+                      cookies={"sid": session_cookie},
+                      files={'datafile': data},
+                      verify=verify)
 
     if r.status_code == 200:
         log.debug("POST request status code: {}".format(r.status_code))
@@ -218,9 +228,10 @@ def upload_runsummary(csv_filename, testrun=False, verify=False):
         return
 
 
-def convert_runsummary_to_json(
-    df, comment="Uploaded via km3pipe.StreamDS", prefix="TEST_"
-):
+def convert_runsummary_to_json(df,
+                               comment='Uploaded via km3pipe.StreamDS',
+                               prefix='TEST_',
+                               isrunsummarystrings=False):
     """Convert a Pandas DataFrame with runsummary to JSON for DB upload"""
     data_field = []
     comment += ", by {}".format(getpass.getuser())
@@ -242,13 +253,19 @@ def convert_runsummary_to_json(
                         entry = {"Name": prefix + parameter_name, "Data": []}
                         parameter_dict[parameter_name] = entry
                     data_value = getattr(row[1], parameter_name)
-                    try:
-                        data_value = float(data_value)
-                    except ValueError as e:
-                        log.critical("Data values has to be floats!")
-                        raise ValueError(e)
-                    value = {"S": str(getattr(row[1], "source")), "D": data_value}
-                    parameter_dict[parameter_name]["Data"].append(value)
+                    if not isrunsummarystrings:
+                        try:
+                            data_value = float(data_value)
+                        except ValueError as e:
+                            log.critical("Data values has to be floats!")
+                            raise ValueError(e)
+                    else:
+                        data_value = str(data_value)
+                    value = {
+                        'S': str(getattr(row[1], 'source')),
+                        'D': data_value
+                    }
+                    parameter_dict[parameter_name]['Data'].append(value)
             for parameter_data in parameter_dict.values():
                 parameters_field.append(parameter_data)
     data_to_upload = {"Comment": comment, "Data": data_field}
